==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/python/Projenrc.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Allows writing projenrc files in python.
 * <p>
 * This will install <code>projen</code> as a Python dependency and will add a
 * <code>synth</code> task which will run <code>.projenrc.py</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.900Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.Projenrc")
public class Projenrc extends io.github.cdklabs.projen.Component {

    protected Projenrc(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Projenrc(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.python.ProjenrcOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.Projenrc}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.Projenrc> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.python.ProjenrcOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) The name of the projenrc file.
         * <p>
         * Default: ".projenrc.py"
         * <p>
         * @return {@code this}
         * @param filename The name of the projenrc file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filename(final java.lang.String filename) {
            this.options().filename(filename);
            return this;
        }

        /**
         * (experimental) The projen version to use.
         * <p>
         * Default: - current version
         * <p>
         * @return {@code this}
         * @param projenVersion The projen version to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenVersion(final java.lang.String projenVersion) {
            this.options().projenVersion(projenVersion);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.python.Projenrc}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.Projenrc build() {
            return new io.github.cdklabs.projen.python.Projenrc(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.python.ProjenrcOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.python.ProjenrcOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/python/Projenrc.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Allows writing projenrc files in python.
 * <p>
 * This will install <code>projen</code> as a Python dependency and will add a
 * <code>synth</code> task which will run <code>.projenrc.py</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.570Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.Projenrc")
public class Projenrc extends io.github.cdklabs.projen.ProjenrcFile {

    protected Projenrc(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Projenrc(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.python.ProjenrcOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) The name of the projenrc file.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFilePath() {
        return software.amazon.jsii.Kernel.get(this, "filePath", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Path to the python executable to use.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getPythonExec() {
        return software.amazon.jsii.Kernel.get(this, "pythonExec", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.Projenrc}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.Projenrc> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.python.ProjenrcOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) The name of the projenrc file.
         * <p>
         * Default: ".projenrc.py"
         * <p>
         * @return {@code this}
         * @param filename The name of the projenrc file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filename(final java.lang.String filename) {
            this.options().filename(filename);
            return this;
        }

        /**
         * (experimental) The projen version to use.
         * <p>
         * Default: - current version
         * <p>
         * @return {@code this}
         * @param projenVersion The projen version to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenVersion(final java.lang.String projenVersion) {
            this.options().projenVersion(projenVersion);
            return this;
        }

        /**
         * (experimental) Path to the python executable to use.
         * <p>
         * Default: "python"
         * <p>
         * @return {@code this}
         * @param pythonExec Path to the python executable to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pythonExec(final java.lang.String pythonExec) {
            this.options().pythonExec(pythonExec);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.python.Projenrc}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.Projenrc build() {
            return new io.github.cdklabs.projen.python.Projenrc(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.python.ProjenrcOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.python.ProjenrcOptions.Builder();
            }
            return this.options;
        }
    }
}
